-------------------------------------------------------------------------------
-- Title      : DIOT Demo Diagnostics package
-- Project    : Distributed I/O Tier
-------------------------------------------------------------------------------
-- File       : diag_pkg.vhd
-- Author     : Greg Daniluk <grzegorz.daniluk@cern.ch>
-- Company    : CERN (BE-CO-HT)
-- Standard   : VHDL
-------------------------------------------------------------------------------
-- Description:
-- This package defines types and constants used by diot_diag module.
-------------------------------------------------------------------------------
--
-- Copyright (c) 2018 CERN
--
-- Copyright and related rights are licensed under the Solderpad Hardware
-- License, Version 0.51 (the “License”) (which enables you, at your option,
-- to treat this file as licensed under the Apache License 2.0); you may not
-- use this file except in compliance with the License. You may obtain a copy
-- of the License at http://solderpad.org/licenses/SHL-0.51.
-- Unless required by applicable law or agreed to in writing, software,
-- hardware and materials distributed under this License is distributed on an
-- “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
-- or implied. See the License for the specific language governing permissions
-- and limitations under the License.
--
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;

package diag_pkg is

  constant c_CMD_FAN_STAT  : integer := 0;
  constant c_CMD_TEMP_STAT : integer := 1;
  constant c_CMD_VOLT_STAT : integer := 2;
  constant c_CMD_FAN_SPEED : integer := 3;
  constant c_CMD_TEMP      : integer := 4;
  
  type t_diag_buf is array (natural range<>) of std_logic_vector(7 downto 0);

  type t_diag_out is record
    err         : std_logic_vector(7 downto 0);
    temp        : t_diag_buf(0 to 1);
    volt1       : t_diag_buf(0 to 1);
    volt2       : t_diag_buf(0 to 1);
    volt3       : t_diag_buf(0 to 1);
    volt4       : t_diag_buf(0 to 1);
    volt5       : t_diag_buf(0 to 1);
    volt6       : t_diag_buf(0 to 1);
    volt7       : t_diag_buf(0 to 1);
    curr1       : t_diag_buf(0 to 1);
    curr2       : t_diag_buf(0 to 1);
    curr3       : t_diag_buf(0 to 1);
    curr4       : t_diag_buf(0 to 1);
    curr5       : t_diag_buf(0 to 1);
    curr6       : t_diag_buf(0 to 1);
    curr7       : t_diag_buf(0 to 1);
  end record;

  constant c_DIAGS_DUMMY : t_diag_out := (x"ff",
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"),
    (x"ff", x"ff"));

end diag_pkg;
