import os
import sys
from nanoxmap import *

dir = str(os.path.dirname(os.path.realpath(__file__)))

project = createProject(dir) 



###############
# configuration
###############

project.setVariantName('NG-MEDIUM')
project.setTopCellName('diot_wic_top')

project.setOptions({'MappingEffort': 'Medium',
                    'TimingDriven':'Yes',
                    'MaxRegisterCount': '5000',
                    'ManageUnconnectedSignals':'Error',
                    'MultiplierToDSPMapThreshold':'1',
                    'UseNxLibrary': 'Yes'})

#project.addMappingDirective('getModels(memory)','RAM','RAM_ECC')



###############
# source files
###############

hdl_dir = '../../'

project.addFile(hdl_dir + 'top/diot_wic_demo/diot_wic_top_nx.vhd')
project.addFile(hdl_dir + 'rtl/wic_modules/wic_pkg.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/genrams/genram_pkg.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/common/gencores_pkg.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/common/gc_sync_ffs.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/common/gc_glitch_filt.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/wishbone/wb_i2c_master/i2c_master_bit_ctrl.vhd')
project.addFile(hdl_dir + 'ip_cores/general-cores/modules/wishbone/wb_i2c_master/i2c_master_byte_ctrl.vhd')
project.addFile(hdl_dir + 'ip_cores/uart.v')
project.addFile(hdl_dir + 'rtl/wic_modules/wic_main.vhd')
project.addFile(hdl_dir + 'rtl/wic_modules/wic_simulator.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/diag_pkg.vhd')
# project.addFile(hdl_dir + 'rtl/diot_diag/diot_diag.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_pkg_gen.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_simple_reg_file.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_sreg_reg_file.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_progmem.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_nx_progmem.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_nx_clkgen.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_sreg_progmem.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_timer.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_alu.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq_fsm.vhd')
project.addFile(hdl_dir + 'rtl/diot_diag/mouseq.vhd')




###############
# constraints
###############

sys.path.append('../../top/diot_wic_demo/')
from diot_wic_demo_nx import setConstraints
setConstraints(project)

project.save('diot_wic_top_native.nxm')



###############
# synthesis
###############

if not project.synthesize():
	sys.exit(1)
project.save('diot_wic_top_synthesized.v')



###############
# routing
###############

if not project.place():
	sys.exit(1)
project.reportPorts()
project.save('diot_wic_top_placed.nxm')
if not project.route():
	sys.exit(1)
project.save('diot_wic_top_routed.nxm')
#reports
#setLogfile('report.log')
project.reportInstances()



###############
# STA
###############

analyzer = project.createAnalyzer()
analyzer.launch()
#analyzer.reportDomains()



###############
# bitstream
###############

project.generateBitstream('diot_wic_top_bitstream.nxb')



###############
# final reports
###############

print 'Errors: ', getErrorCount()
print 'Warnings: ', getWarningCount()
