/*
 * Copyright (C) 2018 CERN
 * Author: Maciej Suminski <maciej.suminski@cern.ch>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <iostream>
#include <QtWidgets/QApplication>
#include "diot_dialog.h"

// Argument values
constexpr int MFIP_INDEX_DEFAULT = 0;
constexpr int MFIP_INDEX_MAX = 7;
constexpr int ADDRESS_DEFAULT = 1;
constexpr int ADDRESS_MAX = 254;
constexpr int SLOTS_NR_DEFAULT = 4;
constexpr int SLOTS_NR_MAX = 8;

static void usage() {
    std::cout << "usage: ./demo [MFIP_index] [address] [slots_number]" << std::endl;
    std::cout << "- MFIP_index is the masterFIP index address (default: "
              << MFIP_INDEX_DEFAULT << ")" << std::endl;
    std::cout << "- address is the nanoFIP agent address (default: "
              << ADDRESS_DEFAULT << ")" << std::endl;
    std::cout << "- slots_number is the number of I/O cards"
              << " (1 <= slots_number <= " << SLOTS_NR_MAX
              << ", default: " << SLOTS_NR_DEFAULT << ")" << std::endl;
}


int main( int argc, char **argv ) {
    QApplication a( argc, argv );

    // Process arguments
    int masterfip_index = MFIP_INDEX_DEFAULT;
    int address = ADDRESS_DEFAULT;
    int slots_nr = SLOTS_NR_DEFAULT;

    if(argc > 4) {
        usage();
        return 0;
    }

    try {
        if(argc > 1)
            masterfip_index = std::stoi(argv[1]);

        if(argc > 2)
            address = std::stoi(argv[2]);

        if(argc > 3)
            slots_nr = std::stoi(argv[3]);

    } catch (...) {
        usage();
        return 1;
    }

    if(slots_nr < 1 || slots_nr > SLOTS_NR_MAX
            || address < 1 || address > ADDRESS_MAX
            || masterfip_index < 0 || masterfip_index > MFIP_INDEX_MAX) {
        usage();
        return 0;
    }

    DIOT_Dialog w(masterfip_index, address, slots_nr);
    w.show();
    return a.exec();
}
